gets the NFS base path from an env var alias for get_nfs_path to maintain backwards compatibility
Source:R/dvloader.R
get_cre_path.Rdgets the NFS base path from an env var alias for get_nfs_path to maintain backwards compatibility
R/dvloader.R
get_cre_path.Rdgets the NFS base path from an env var alias for get_nfs_path to maintain backwards compatibility