gets the NFS base path from an env var It assumes there is an env var called RXD_DATA which holds the path suffix.
Source:R/dvloader.R
get_nfs_path.Rdgets the NFS base path from an env var It assumes there is an env var called RXD_DATA which holds the path suffix.