Read data from provided paths and return it as a list of data frames. Supports both .rds and .sas7bdat formats.
Arguments
- file_paths
[character(1+)]Files to read. Optionally named.- reduce_memory_footprint
[logical(1)]If TRUE, character variables are mapped into factors and floating-point variables are mapped into integers, as long as the conversion does not lead to loss of precision.
If FALSE, this function respects the original types returned by the underlying calls to
base::readRDSandhaven::read_sas.- encoding
[character(1) | NULL]Character encoding to use when reading.sas7bdatfiles. A value ofNULL(the default) uses the encoding declared in the file. Ignored for.rdsfiles.