Collect file paths based on file names without extensions
Source:R/utils.R
collect_data_list_paths.RdConstructs a list of file paths based on an input vector of file names without extensions.
Preference is given to .rds files, if present, over .sas7bdat files.
Arguments
- sub_dir
A relative directory/folder that will be appended to a base path defined by
Sys.getenv("RXD_DATA"). If the argument is left as NULL, the function will load data from the working directorygetwd().- file_names
CDISC names for the files
- use_wd
for "use working directory" - a flag used when importing local files not on NFS - default value is FALSE
- prefer_sas
if TRUE, imports .sas7bdat files first instead of .RDS files