Transform data.frame column to use leaner types
Source:R/dvloader.R
reduce_column_memory_footprint.RdTransforms a character column into a factor or a numeric column into integer, when the transformation does not lead to loss of precision.
R/dvloader.R
reduce_column_memory_footprint.RdTransforms a character column into a factor or a numeric column into integer, when the transformation does not lead to loss of precision.